@@ -1,40 +1,45 @@
 /*
-SPDX-FileCopyrightText: 2002-2004 Otto Bruggeman <otto.bruggeman@home.nl>
-SPDX-FileCopyrightText: 2010 Kevin Kofler <kevin.kofler@chello.at>
+    SPDX-FileCopyrightText: 2002-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+    SPDX-FileCopyrightText: 2010 Kevin Kofler <kevin.kofler@chello.at>
 
-SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef KOMPAREDIFF2_PARSERBASE_H
 #define KOMPAREDIFF2_PARSERBASE_H
 
+// lib
+#include "difference.h"
+#include "global.h"
+// Qt
 #include <QRegularExpression>
 #include <QStringList>
 
-#include "kompare.h"
-#include "difference.h"
-
 class QString;
 
-namespace Diff2
+namespace KompareDiff2
 {
 
-class KompareModelList;
+class ModelList;
 class DiffModelList;
 class DiffModel;
 
 class ParserBase
 {
 public:
-    ParserBase(const KompareModelList* list, const QStringList& diff);
+    ParserBase(const ModelList *list, const QStringList &diff);
     virtual ~ParserBase();
 
     static QString escapePath(QString path);
     static QString unescapePath(QString path);
 
 public:
-    enum Kompare::Format format() { return determineFormat(); };
-    DiffModelList* parse(bool* malformed = nullptr);
+    Format format()
+    {
+        return determineFormat();
+    };
+
+    DiffModelList *parse(bool *malformed = nullptr);
 
 protected:
     virtual bool parseContextDiffHeader();
@@ -55,19 +60,19 @@ protected:
     virtual bool parseRCSHunkBody();
     virtual bool parseUnifiedHunkBody();
 
-    virtual DiffModelList* parseContext();
-    virtual DiffModelList* parseEd();
-    virtual DiffModelList* parseNormal();
-    virtual DiffModelList* parseRCS();
-    virtual DiffModelList* parseUnified();
+    virtual DiffModelList *parseContext();
+    virtual DiffModelList *parseEd();
+    virtual DiffModelList *parseNormal();
+    virtual DiffModelList *parseRCS();
+    virtual DiffModelList *parseUnified();
 
 protected: // Helper methods to speed things up
-    bool matchesUnifiedHunkLine(const QString& line) const;
-    void checkHeader(const QRegularExpression& header);
+    bool matchesUnifiedHunkLine(const QString &line) const;
+    void checkHeader(const QRegularExpression &header);
 
 protected:
     /** What is format of the diff */
-    virtual enum Kompare::Format determineFormat();
+    virtual Format determineFormat();
 
 protected:
     // Regexps for context parsing
@@ -100,7 +105,7 @@ protected:
     QRegularExpression m_normalHunkBodyAdded;
     QRegularExpression m_normalHunkBodyDivider;
 
-    enum Difference::Type m_normalDiffType;
+    Difference::Type m_normalDiffType;
 
     // RegExps for rcs parsing
     QRegularExpression m_rcsDiffHeader;
@@ -113,18 +118,18 @@ protected:
     QRegularExpressionMatch m_unifiedHunkHeaderMatch;
 
 protected:
-    const QStringList&         m_diffLines;
-    DiffModel*                 m_currentModel;
-    DiffModelList*             m_models;
+    const QStringList &m_diffLines;
+    DiffModel *m_currentModel = nullptr;
+    DiffModelList *m_models = nullptr;
     QStringList::ConstIterator m_diffIterator;
 
-    bool                       m_singleFileDiff;
-    bool                       m_malformed;
+    bool m_singleFileDiff = false;
+    bool m_malformed = false;
 
 protected:
-    const KompareModelList* m_list;
+    const ModelList *m_list;
 };
 
-} // End of namespace Diff2
+} // End of namespace KompareDiff2
 
 #endif
